@@ -49,7 +49,7 @@ def condexp_num(
     df = x.assign(pred=pred, y=y)
     if df[var].nunique() > n_cut:
         groupvar = df[var] + 1e-6 * np.random.uniform(size=len(df))
-        df["groups"] = pd.qcut(groupvar, 10)
+        df["groups"] = pd.qcut(groupvar, n_cut, duplicates="drop")
     else:
         df["groups"] = df[var]
 
